pub struct SystemOneService {
pub state: AppState,
pub auth: AuthConfig,
}Expand description
gRPC service implementation of the openkind.SystemOne service contract.
Fields
state: AppStateShared application state containing the model registry.
auth: AuthConfigAuthentication configuration.
Implementations
Sourceimpl SystemOneService
impl SystemOneService
Sourcepub fn new(registry: EngineRegistry) -> SystemOneService
pub fn new(registry: EngineRegistry) -> SystemOneService
Construct a new SystemOneService backed by the specified engine registry and default auth.
Sourcepub fn with_auth(registry: EngineRegistry, auth: AuthConfig) -> SystemOneService
pub fn with_auth(registry: EngineRegistry, auth: AuthConfig) -> SystemOneService
Construct a new SystemOneService backed by the specified engine registry and auth configuration.